// --------------------------------------------------------------------------------------------------------------------
// <copyright file="PageHistory.cs" company="ecblog.codeplex.com">
//   emrecoskun.net - ibrahimatay.com
// </copyright>
// <summary>
//   The page history
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace EcBlog.Models
{
    using System;
    using System.ComponentModel.DataAnnotations;

    // using System.ComponentModel.DataAnnotations.Schema;

    /// <summary>
    /// The page history
    /// </summary>
    public sealed class PageHistory
    {
        /// <summary>
        /// Gets or sets the page history id.
        /// </summary>
        /// <value>
        /// The page history id.
        /// </value>
        [Key]
        [DatabaseGenerated(DatabaseGeneratedOption.Identity)]
        public long PageHistoryId { get; set; }

        /// <summary>
        /// Gets or sets the page id.
        /// </summary>
        /// <value>
        /// The page id.
        /// </value>
        public long PageId { get; set; }

        /// <summary>
        /// Gets or sets the title.
        /// </summary>
        /// <value>
        /// The title.
        /// </value>
        [Required][StringLength(500)]
        public string Title { get; set; }

        /// <summary>
        /// Gets or sets the slug.
        /// </summary>
        /// <value>
        /// The slug.
        /// </value>
        [Required, StringLength(500)]
        public string Slug { get; set; }

        /// <summary>
        /// Gets or sets the content HTML.
        /// </summary>
        /// <value>
        /// The content HTML.
        /// </value>
        [Column(TypeName = "ntext")]
        [MaxLength]
        public string ContentHtml { get; set; }

        /// <summary>
        /// Gets or sets the layout id.
        /// </summary>
        /// <value>
        /// The layout id.
        /// </value>
        public long LayoutId { get; set; }

        /// <summary>
        /// Gets or sets a value indicating whether this instance is commentable.
        /// </summary>
        /// <value>
        ///    <c>true</c> if this instance is commentable; otherwise, <c>false</c>.
        /// </value>
        public bool IsCommentable { get; set; }

        /// <summary>
        /// Gets or sets a value indicating whether this instance is publish.
        /// </summary>
        /// <value>
        ///     <c>true</c> if this instance is publish; otherwise, <c>false</c>.
        /// </value>
        public bool IsPublish { get; set; }

        /// <summary>
        /// Gets or sets the published.
        /// </summary>
        /// <value>
        /// The published.
        /// </value>
        [DataType(DataType.DateTime)]
        public DateTime Published { get; set; }

        /// <summary>
        /// Gets or sets the created.
        /// </summary>
        /// <value>
        /// The created.
        /// </value>
        [ScaffoldColumn(false)]
        public DateTime Created { get; set; }

        /// <summary>
        /// Gets or sets a value indicating whether [show post list].
        /// </summary>
        /// <value>
        ///   <c>true</c> if [show post list]; otherwise, <c>false</c>.
        /// </value>
        public bool ShowPostList { get; set; }

        /// <summary>
        /// Gets or sets the summary.
        /// </summary>
        /// <value>
        /// The summary.
        /// </value>
        [DataType(DataType.MultilineText)]
        [Column(TypeName = "ntext")]
        [MaxLength]
        public string Summary { get; set; }

        /// <summary>
        /// Gets or sets the last modified.
        /// </summary>
        /// <value>
        /// The last modified.
        /// </value>
        public DateTime LastModified { get; set; }

        /// <summary>
        /// Gets or sets the last modified user.
        /// </summary>
        /// <value>
        /// The last modified user.
        /// </value>
        [StringLength(50)]
        public string LastModifiedUser { get; set; }

        /// <summary>
        /// Gets or sets the operation.
        /// </summary>
        /// <value>
        /// The operation.
        /// </value>
        public CrudOperation Operation { get; set; }
    }
}